# Yap All You Want (YAYW) on Threads

You want to yap and you want people to see on Threads. You are too lazy to split your BS into posts and replies. This tool does that for you.

## Usage

```shell
pip install yayw

export YAYW_USER_ID="<YOUR THREADS USER ID>"
export YAYW_ACCESS_TOKEN="<YOUR THREADS ACCESS TOKEN>" # This maybe a little hard to locate, but I have faith in you.

yayw YOUR_LONG_ASS_RANT.txt
```
